ImageDenoiserClassic - Classic Image Denoiser
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ImageDenoiserClassic
*********************

.. currentmodule:: aydin.it.classic

.. autoclass:: ImageDenoiserClassic
    :members:
    :inherited-members:


Procedural calibration and denoising API:
*******************************************

Bilateral
===========
    .. currentmodule:: aydin.it.classic_denoisers.bilateral

    .. autofunction:: calibrate_denoise_bilateral
    .. autofunction:: denoise_bilateral

BMND
===========
    .. currentmodule:: aydin.it.classic_denoisers.bmnd

    .. autofunction:: calibrate_denoise_bmnd
    .. autofunction:: denoise_bmnd

Butterworth
=============
    .. currentmodule:: aydin.it.classic_denoisers.butterworth

    .. autofunction:: calibrate_denoise_butterworth
    .. autofunction:: denoise_butterworth

Dictionary fixed
==================
    .. currentmodule:: aydin.it.classic_denoisers.dictionary_fixed

    .. autofunction:: calibrate_denoise_dictionary_fixed
    .. autofunction:: denoise_dictionary_fixed

Dictionary learned
===================
    .. currentmodule:: aydin.it.classic_denoisers.dictionary_learned

    .. autofunction:: calibrate_denoise_dictionary_learned
    .. autofunction:: denoise_dictionary_learned

Gaussian
=============
    .. currentmodule:: aydin.it.classic_denoisers.gaussian

    .. autofunction:: calibrate_denoise_gaussian
    .. autofunction:: denoise_gaussian

Gaussian-Median
================
    .. currentmodule:: aydin.it.classic_denoisers.gm

    .. autofunction:: calibrate_denoise_gm
    .. autofunction:: denoise_gm

Harmonic
=============
    .. currentmodule:: aydin.it.classic_denoisers.harmonic

    .. autofunction:: calibrate_denoise_harmonic
    .. autofunction:: denoise_harmonic

Lipschitz
=============
    .. currentmodule:: aydin.it.classic_denoisers.lipschitz

    .. autofunction:: calibrate_denoise_lipschitz
    .. autofunction:: denoise_lipschitz

Non-Local Means(NLM)
=====================
    .. currentmodule:: aydin.it.classic_denoisers.nlm

    .. autofunction:: calibrate_denoise_nlm
    .. autofunction:: denoise_nlm

PCA
=====================
    .. currentmodule:: aydin.it.classic_denoisers.pca

    .. autofunction:: calibrate_denoise_pca
    .. autofunction:: denoise_pca

Spectral
=====================
    .. currentmodule:: aydin.it.classic_denoisers.spectral

    .. autofunction:: calibrate_denoise_spectral
    .. autofunction:: denoise_spectral

Total Variation(TV)
=====================
    .. currentmodule:: aydin.it.classic_denoisers.tv

    .. autofunction:: calibrate_denoise_tv
    .. autofunction:: denoise_tv

Wavelet
=====================
    .. currentmodule:: aydin.it.classic_denoisers.wavelet

    .. autofunction:: calibrate_denoise_wavelet
    .. autofunction:: denoise_wavelet
